import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = [
  'https://gist.githubusercontent.com/prajoth0405/5975bdf28c3c6c66ccf63bdc74d49e4b/raw/b3e2fe8ba6dc9aa8427ea9e127c28327b0a06360/gistfile1.txt', // File name
].join('');
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// selecting the specified species
const xValue = (d) => d.petal_width;
const yValue = (d) => d.sepal_length;
const rxValue = (d) => d.petal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species;

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){
            case 'versicolor':
              return 'red';
            case 'virginica':
              return 'green';
            default:
              return 'orange'; // The specified color for species is selected
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d), // Mapping function is used for data to run the required fields
                      
        }));
  
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(4);
  svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
  //y axis label
    svg.append("text")
        .attr("x",-300)
        .attr("y",15)
        .attr("font-size","15px")
        .attr("transform","rotate(-90)")
        .text("Sepal length")
        
          //x axis label
    svg.append("text")
        .attr("x",400)
        .attr("y",500)
        .attr("font-size","23px")
        .text("Petal Length")

  svg.call(plot);

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();



